# Furo

A clean customisable documentation theme for Sphinx.

NOTE: This is a WIP project, but this theme's own documentation is rendered using itself, and can be found at https://pradyunsg.me/furo/quickstart/.
